.. :changelog:

Changelog
=========

v0.0.8.1
--------
Release Date: 2021-01-19
    * Bug Fixed.

v0.0.8
------
Release Date: 2021-01-17
    * Bug Fixed.

v0.0.7
------
Release Date: 2021-01-17
    * Bug Fixed.

v0.0.6
------
Release Date: 2021-01-16
    * Added redis as in memory storage.

v0.0.5
------
Release Date: 2021-01-16
    * Added garbage collector.

v0.0.4
------
Release Date: 2021-01-16
    * Added Validator to limiter.

v0.0.3
------
Release Date: 2021-01-14
    * Added callable function for limitation and key function.

v0.0.2
------
Release Date: 2021-01-14
    * Bug fixed.

v0.0.1
------
Release Date: 2021-01-13
    * Basic Function Limiter.